
/**
* jQuery UI 1.9m6 resource composition
* You have to use juicer to produce a minified resource based on this file
* You cannot use this file as a development resource
*
* Core files:
*     @depends 1.9m5/external/jquery.bgiframe-2.1.2.js        
*     @depends 1.9m5/ui/jquery.ui.core.js        
*     @depends 1.9m5/ui/jquery.ui.widget.js       
*     @depends 1.9m5/ui/jquery.ui.mouse.js          
*    
* Behaviour:
*     @depends 1.9m5/ui/jquery.ui.draggable.js
*     @depends 1.9m5/ui/jquery.ui.droppable.js
*     @depends 1.9m5/ui/jquery.ui.resizable.js
*     @depends 1.9m5/ui/jquery.ui.selectable.js
*     @depends 1.9m5/ui/jquery.ui.sortable.js
*    
* Widgets:
*     @depends 1.9m5/ui/jquery.ui.accordion.js
*     @depends 1.9m5/ui/jquery.ui.autocomplete.js
*     @depends 1.9m5/ui/jquery.ui.button.js
*     @depends 1.9m5/ui/jquery.ui.datepicker.js        
*     @depends 1.9m5/ui/jquery.ui.dialog.js
*     @depends 1.9m5/ui/jquery.ui.menu.js
*     @depends 1.9m5/ui/jquery.ui.menubar.js
*     @depends 1.9m5/ui/jquery.ui.popup.js        
*     @depends 1.9m5/ui/jquery.ui.position.js        
*     @depends 1.9m5/ui/jquery.ui.progressbar.js
*     @depends 1.9m5/ui/jquery.ui.slider.js
*     @depends 1.9m5/ui/jquery.ui.spinner.js
*     @depends 1.9m5/ui/jquery.ui.tabs.js
*     @depends 1.9m5/ui/jquery.ui.tooltip.js
* 
* Effects:
*     @depends 1.9m5/ui/jquery.effects.core.js        
*     @depends 1.9m5/ui/jquery.effects.core.js        
*     @depends 1.9m5/ui/jquery.effects.bounce.js
*     @depends 1.9m5/ui/jquery.effects.clip.js
*     @depends 1.9m5/ui/jquery.effects.drop.js
*     @depends 1.9m5/ui/jquery.effects.explode.js
*     @depends 1.9m5/ui/jquery.effects.fade.js
*     @depends 1.9m5/ui/jquery.effects.fold.js
*     @depends 1.9m5/ui/jquery.effects.highlight.js
*     @depends 1.9m5/ui/jquery.effects.pulsate.js        
*     @depends 1.9m5/ui/jquery.effects.scale.js
*     @depends 1.9m5/ui/jquery.effects.shake.js
*     @depends 1.9m5/ui/jquery.effects.slide.js
*     @depends 1.9m5/ui/jquery.effects.transfer.js
* 
* Extras, not currently in release:
*     @depends 1.9m5-extras/jquery.ui.selectmenu.js
*
*
*
*/

