
/**
* TinyMCE resource composition
* You have to use juicer to produce a minified resource based on this file
* You cannot use this file as a development resource
*
* ... Like plugins1, but without the broken autosave plugin.
*
* Static loading:
*     @depends 3.4.8-extras/jquery.tinysafe.js
*
* Editor and theme:
*     @depends 3.4.8/jscripts/tiny_mce/tiny_mce_src.js
*     @depends 3.4.8/jscripts/tiny_mce/langs/en.js
*     @depends 3.4.8/jscripts/tiny_mce/themes/advanced/editor_template_src.js
*     @depends 3.4.8/jscripts/tiny_mce/themes/advanced/langs/en.js
*
* Paste plugin:
*     @depends 3.4.8/jscripts/tiny_mce/plugins/paste/editor_plugin_src.js
*
* Spellchecker plugin:
*     @depends 3.4.8/jscripts/tiny_mce/plugins/spellchecker/editor_plugin_src.js
* 
* Advlist plugin:
*     @depends 3.4.8/jscripts/tiny_mce/plugins/advlist/editor_plugin_src.js
*
* Lists plugin:
*     @depends 3.4.8/jscripts/tiny_mce/plugins/lists/editor_plugin_src.js
*
* Print plugin:
*     @depends 3.4.8/jscripts/tiny_mce/plugins/print/editor_plugin_src.js
*
* Table plugin:
*     @depends 3.4.8/jscripts/tiny_mce/plugins/table/editor_plugin_src.js
*
*/
