
/**
* Slickgrid v2.0a jslibrev1 resource composition
* An untagged revision from git, we call jslibrev1 as our tag in jslibs.
* jslibrev1 = revision 5f88203f4b3c70eed7feaf31e65d71d95d2272c5 from git
*
* You have to use juicer to produce a minified resource based on this file
* You can also use this file as a development resource
*
*/

@import url("v2.0a-jslibrev1/slick.grid.css");


