
/**
* Slickgrid v2.0a jslibrev1 resource composition
* An untagged revision from git, we call jslibrev1 as our tag in jslibs.
* jslibrev1 = revision 5f88203f4b3c70eed7feaf31e65d71d95d2272c5 from git
*
* You have to use juicer to produce a minified resource based on this file
* You cannot use this file as a development resource
*
* External dependencies:
*     @depends v2.0a-jslibrev1-extras/jquery.event.drag-2.0-fixed.js
*     @depends v2.0a-jslibrev1/lib/jquery.event.drop-2.0.min.js
*
* Core files:
*     @depends v2.0a-jslibrev1/slick.core.js
*     @depends v2.0a-jslibrev1/slick.editors.js
*
* Plugins:
*     @depends v2.0a-jslibrev1/plugins/slick.cellrangedecorator.js
*     @depends v2.0a-jslibrev1/plugins/slick.cellrangeselector.js
*     @depends v2.0a-jslibrev1/plugins/slick.cellselectionmodel.js
*     @depends v2.0a-jslibrev1/plugins/slick.rowselectionmodel.js
*
*     @depends v2.0a-jslibrev1/plugins/slick.autotooltips.js
*     @depends v2.0a-jslibrev1/plugins/slick.cellcopymanager.js
*     @depends v2.0a-jslibrev1/plugins/slick.checkboxselectcolumn.js
*     @depends v2.0a-jslibrev1/plugins/slick.rowmovemanager.js
*
* More core files:
*     @depends v2.0a-jslibrev1/slick.grid.js
*     @depends v2.0a-jslibrev1/slick.dataview.js
*
*
*
*/

