
/**
* jQuery UI 1.9m5 resource composition
* You have to use juicer to produce a minified resource based on this file
* You can also use this file as a development resource
*
* This css contains jquery-ui without any theme.
* You can use it if you want to provide your own theme css with it.
*
*/

@import url("1.9m5/themes/base/jquery.ui.core.css");
@import url("1.9m5/themes/base/jquery.ui.accordion.css");
@import url("1.9m5/themes/base/jquery.ui.autocomplete.css");
@import url("1.9m5/themes/base/jquery.ui.button.css");
@import url("1.9m5/themes/base/jquery.ui.datepicker.css");
@import url("1.9m5/themes/base/jquery.ui.dialog.css");
@import url("1.9m5/themes/base/jquery.ui.menu.css");
/*@ NOT import url("1.9m5/themes/base/jquery.ui.menubar.css");*/ /*NOT in m5 yet!*/
@import url("1.9m5/themes/base/jquery.ui.progressbar.css");
@import url("1.9m5/themes/base/jquery.ui.resizable.css");
@import url("1.9m5/themes/base/jquery.ui.selectable.css");
@import url("1.9m5/themes/base/jquery.ui.slider.css");
@import url("1.9m5/themes/base/jquery.ui.spinner.css");
@import url("1.9m5/themes/base/jquery.ui.tabs.css");
@import url("1.9m5/themes/base/jquery.ui.tooltip.css");

/* Extras, not currently in release */
@import url("1.9m5-extras/jquery.ui.selectmenu.css");


