
/**
* jQuery UI 1.9m5 resource composition
* You have to use juicer to produce a minified resource based on this file
* You can also use this file as a development resource
*
* This css contains jquery-ui with the Smoothness theme
*
*/

@import url("jquery-ui-1.9m5-unthemed.css");
@import url("jquery-ui-theme-smoothness.css");

