

/**
* JQuery 1.6.2 resource composition
* You have to use juicer to produce a minified resource based on this file
* You cannot use this file as a development resource
*
* JQuery:
*     @depends 1.6.2/src/intro.js 
*
*     @depends 1.6.2/src/core.js
*     @depends 1.6.2/src/deferred.js 
*     @depends 1.6.2/src/support.js 
*     @depends 1.6.2/src/data.js 
*     @depends 1.6.2/src/queue.js 
*     @depends 1.6.2/src/attributes.js 
*     @depends 1.6.2/src/event.js 
*     @depends 1.6.2/src/selector.js 
*     @depends 1.6.2/src/traversing.js 
*     @depends 1.6.2/src/manipulation.js 
*     @depends 1.6.2/src/css.js 
*     @depends 1.6.2/src/ajax.js 
*     @depends 1.6.2/src/ajax/jsonp.js 
*     @depends 1.6.2/src/ajax/script.js 
*     @depends 1.6.2/src/ajax/xhr.js 
*     @depends 1.6.2/src/effects.js 
*     @depends 1.6.2/src/offset.js 
*     @depends 1.6.2/src/dimensions.js 
*
*     @depends 1.6.2/src/outro.js 
*
*/
