
/**
* TinyMCE resource composition
* You have to use juicer to produce a minified resource based on this file
* You can also use this file as a development resource
*
*
* XXX TODO. Load all tiny css this way. (As, this only loads the ui css)
*
*/

@import url("3.5b3/jscripts/tiny_mce/themes/advanced/skins/default/ui.css");

