
/**
* bottlecap HEAD resource composition
* You have to use juicer to produce a minified resource based on this file
* You cannot use this file as a development resource
*
*
* HEAD resources:
*     @depends 0/modernizr-2.0.6.min.js
*     @depends 0/respond.min.js
*     @depends ../jquery/jquery-1.6.2.js
*
*/
